@@ -88,6 +88,7 @@ class BotAntiCaptchaPlugin:
         task = FunCaptchaProxylessTask(url, site_key)
         self._last_job = self._client.createTask(task)
         self._last_job.join(timeout)
+        self._last_job_type = "fun"
 
         # Returns the result in token format
         return self._last_job.get_token_response()
@@ -119,9 +120,11 @@ class BotAntiCaptchaPlugin:
 
         # Reports according to the captcha type
         if self._last_job_type == "text":
-            self._last_job.reportIncorrectImage()
+            self._last_job.report_incorrect_image()
         elif self._last_job_type == "re":
-            self._last_job.reportIncorrectRecaptcha()
+            self._last_job.report_incorrect_recaptcha()
+        elif self._last_job_type == "fun":
+            raise NotImplementedError('Fun Captcha error report is not supported at the moment.')
 
         return self
 
